@@ -1,4 +1,4 @@
-use std::{any::Any, marker::PhantomData};
+use std::marker::PhantomData;
 
 use async_trait::async_trait;
 use tokio::sync::{mpsc, oneshot};
@@ -8,7 +8,7 @@ use crate::{actor::{ActorContext, Handler, Message}, system::SystemEvent};
 use super::{Actor, ActorError};
 
 #[async_trait]
-pub trait MessageHandler<A: Actor, E: SystemEvent>: Send + Sync {
+pub trait MessageHandler<A: Actor<E>, E: SystemEvent>: Send + Sync {
 
     async fn handle(&mut self, actor: &mut A, ctx: &mut ActorContext<E>);
 }
@@ -17,7 +17,7 @@ struct ActorMessage<M, A, E>
 where
     M: Message,
     E: SystemEvent,
-    A: Actor + Handler<M, E>,
+    A: Actor<E> + Handler<M, E>,
 {
     payload: M,
     rsvp: Option<oneshot::Sender<M::Response>>,
@@ -30,7 +30,7 @@ impl<M, A, E> MessageHandler<A, E> for ActorMessage<M, A, E>
 where
     M: Message,
     E: SystemEvent,
-    A: Actor + Handler<M, E>,
+    A: Actor<E> + Handler<M, E>,
 {
     async fn handle(&mut self, actor: &mut A, ctx: &mut ActorContext<E>) {
         self.process(actor, ctx).await
@@ -41,7 +41,7 @@ impl<M, A, E> ActorMessage<M, A, E>
 where
     M: Message,
     E: SystemEvent,
-    A: Actor + Handler<M, E>,
+    A: Actor<E> + Handler<M, E>,
 {
 
     async fn process(&mut self, actor: &mut A, ctx: &mut ActorContext<E>) {
@@ -68,12 +68,12 @@ where
 pub type MailboxReceiver<A, E> = mpsc::UnboundedReceiver<BoxedMessageHandler<A, E>>;
 pub type MailboxSender<A, E> = mpsc::UnboundedSender<BoxedMessageHandler<A, E>>;
 
-pub struct ActorMailbox<A: Actor, E: SystemEvent> {
+pub struct ActorMailbox<A: Actor<E>, E: SystemEvent> {
     _phantom_actor: PhantomData<A>,
     _phantom_event: PhantomData<E>
 }
 
-impl<A: Actor, E: SystemEvent> ActorMailbox<A, E> {
+impl<A: Actor<E>, E: SystemEvent> ActorMailbox<A, E> {
 
     pub fn create() -> (MailboxSender<A, E>, MailboxReceiver<A, E>) {
         mpsc::unbounded_channel()
@@ -81,35 +81,13 @@ impl<A: Actor, E: SystemEvent> ActorMailbox<A, E> {
 }
 
 pub type BoxedMessageHandler<A, E> = Box<dyn MessageHandler<A, E>>;
-pub type AnyMessageHandler = Box<dyn Any + Sync + Send>;
 
 #[derive(Clone)]
-pub struct HandlerRef<A: Actor, E: SystemEvent> {
+pub struct HandlerRef<A: Actor<E>, E: SystemEvent> {
     sender: mpsc::UnboundedSender<BoxedMessageHandler<A, E>>
 }
 
-#[derive(Clone)]
-pub struct AnyHandlerRef {
-    pub sender: mpsc::UnboundedSender<AnyMessageHandler>
-}
-
-impl<A: Actor, E: SystemEvent> From<AnyHandlerRef> for HandlerRef<A, E> {
-    fn from(handler: AnyHandlerRef) -> Self {
-        HandlerRef {
-            sender: unsafe { std::mem::transmute(handler.sender) }
-        }
-    }
-}
-
-impl<A: Actor, E: SystemEvent> From<HandlerRef<A, E>> for AnyHandlerRef {
-    fn from(handler: HandlerRef<A, E>) -> Self {
-        AnyHandlerRef {
-            sender: unsafe { std::mem::transmute(handler.sender) }
-        }
-    }
-}
-
-impl<A: Actor, E: SystemEvent> HandlerRef<A, E> {
+impl<A: Actor<E>, E: SystemEvent> HandlerRef<A, E> {
 
     pub(crate) fn new(sender: mpsc::UnboundedSender<BoxedMessageHandler<A, E>>) -> Self {
         HandlerRef {
@@ -152,10 +130,9 @@ impl<A: Actor, E: SystemEvent> HandlerRef<A, E> {
 #[cfg(test)]
 mod tests {
 
-    use crate::{bus::EventBus, system::ActorSystem};
+    use crate::{ActorPath, bus::EventBus, system::ActorSystem};
 
     use super::*;
-    use uuid::Uuid;
 
     #[derive(Clone)]
     struct MyActor {
@@ -181,7 +158,7 @@ mod tests {
         }
     }
 
-    impl Actor for MyActor {}
+    impl Actor<MyMessage> for MyActor {}
 
     #[tokio::test]
     async fn actor_tell() {
@@ -199,8 +176,8 @@ mod tests {
         };
         let bus = EventBus::<MyMessage>::new(1000);
         let system = ActorSystem::new("test", bus);
-        let id =  Uuid::new_v4();
-        let mut ctx = ActorContext { id, system };
+        let path = ActorPath::from("/test");
+        let mut ctx = ActorContext { path, system };
         tokio::spawn( async move {
             while let Some(mut msg) = receiver.recv().await {
                 msg.handle(&mut actor, &mut ctx).await;
@@ -228,8 +205,8 @@ mod tests {
         };
         let bus = EventBus::<MyMessage>::new(1000);
         let system = ActorSystem::new("test", bus);
-        let id =  Uuid::new_v4();
-        let mut ctx = ActorContext { id, system };
+        let path = ActorPath::from("/test");
+        let mut ctx = ActorContext { path, system };
         tokio::spawn( async move {
             while let Some(mut msg) = receiver.recv().await {
                 msg.handle(&mut actor, &mut ctx).await;
@@ -239,36 +216,4 @@ mod tests {
         let result = actor_ref.ask(msg).await.unwrap();
         assert_eq!(result, 1);
     }
-
-    #[tokio::test]
-    async fn ref_transmute() {
-
-        if std::env::var("RUST_LOG").is_err() {
-            std::env::set_var("RUST_LOG", "trace");
-        }
-        let _ = env_logger::builder().is_test(true).try_init();
-
-        let mut actor = MyActor { counter: 0 };
-        let msg = MyMessage("Hello World!".to_string());
-        let (sender, mut receiver): (MailboxSender<MyActor, MyMessage>, MailboxReceiver<MyActor, MyMessage>) = ActorMailbox::create();
-        let actor_ref = HandlerRef {
-            sender
-        };
-        let any_ref: AnyHandlerRef = actor_ref.into();
-        let bus = EventBus::<MyMessage>::new(1000);
-        let system = ActorSystem::new("test", bus);
-        let id =  Uuid::new_v4();
-        let mut ctx = ActorContext { id, system };
-        tokio::spawn( async move {
-            while let Some(mut msg) = receiver.recv().await {
-                msg.handle(&mut actor, &mut ctx).await;
-            }
-        });
-
-        let mut check: HandlerRef<MyActor, MyMessage> = any_ref.into();
-        check.tell(msg).unwrap();
-
-        tokio::time::sleep(tokio::time::Duration::from_millis(1000)).await;
-    }
-
 }
\ No newline at end of file
