@@ -1,5 +1,13 @@
 use tiny_tokio_actor::*;
 
+// The event message you may want to publish to the
+// system event bus.
+#[derive(Clone, Debug)]
+struct TestEvent(String);
+
+// Mark the struct as a system event message.
+impl SystemEvent for TestEvent {}
+
 // The actor struct must derive Clone.
 #[derive(Clone)]
 struct TestActor {
@@ -7,7 +15,7 @@ struct TestActor {
 }
 
 // Mark the struct as an actor.
-impl Actor for TestActor {}
+impl Actor<TestEvent> for TestActor {}
 
 // The message the actor will expect. It must
 // derive Clone. Debug is not required.
@@ -22,14 +30,6 @@ impl Message for TestMessage {
     type Response = String;
 }
 
-// The event message you may want to publish to the
-// system event bus.
-#[derive(Clone, Debug)]
-struct TestEvent(String);
-
-// Mark the struct as a system event message.
-impl SystemEvent for TestEvent {}
-
 // Define the behaviour of the actor. Note that the `handle` method
 // has a `String` return type because that is what we defined the
 // Response to be of `TestMessage`. As the method is async, we have
@@ -42,7 +42,7 @@ impl Handler<TestMessage, TestEvent> for TestActor {
         self.counter += 1;
         log::debug!("counter is now {}", &self.counter);
         log::debug!("actor on system {}", ctx.system.get_name());
-        ctx.system.publish(TestEvent(format!("message received by '{}'", ctx.id)));
+        ctx.system.publish(TestEvent(format!("message received by '{}'", ctx.path)));
         "Ping!".to_string()
     }
 }
@@ -64,7 +64,7 @@ async fn simple_message() {
     // Create the actor system with the event bus
     let system = ActorSystem::new("test", bus);
     // Launch the actor on the actor system
-    let mut actor_ref = system.create_actor(actor).await;
+    let mut actor_ref = system.create_actor("test-actor", actor).await.unwrap();
 
     // Listen for events on the system event bus
     let mut events = system.events();
